@@ -45,6 +45,7 @@
 #define IDE_VERSION_3_36 (G_ENCODE_VERSION (3, 36))
 #define IDE_VERSION_3_38 (G_ENCODE_VERSION (3, 38))
 #define IDE_VERSION_3_40 (G_ENCODE_VERSION (3, 40))
+#define IDE_VERSION_41 (G_ENCODE_VERSION (41, 0))
 
 #if (IDE_MINOR_VERSION == 99)
 # define IDE_VERSION_CUR_STABLE (G_ENCODE_VERSION (IDE_MAJOR_VERSION + 1, 0))
@@ -214,3 +215,17 @@
 #else
 # define IDE_AVAILABLE_IN_3_40                 _IDE_EXTERN
 #endif
+
+#if IDE_VERSION_MIN_REQUIRED >= IDE_VERSION_41
+# define IDE_DEPRECATED_IN_41                IDE_DEPRECATED
+# define IDE_DEPRECATED_IN_41_FOR(f)         IDE_DEPRECATED_FOR(f)
+#else
+# define IDE_DEPRECATED_IN_41                _IDE_EXTERN
+# define IDE_DEPRECATED_IN_41_FOR(f)         _IDE_EXTERN
+#endif
+
+#if IDE_VERSION_MAX_ALLOWED < IDE_VERSION_41
+# define IDE_AVAILABLE_IN_41                 IDE_UNAVAILABLE(41, 0)
+#else
+# define IDE_AVAILABLE_IN_41                 _IDE_EXTERN
+#endif
