@@ -18,6 +18,8 @@
  * SPDX-License-Identifier: GPL-3.0-or-later
  */
 
+#include <jsonrpc-glib.h>
+
 #include "ide-lsp-util.h"
 
 IdeSymbolKind
@@ -86,3 +88,59 @@ ide_lsp_decode_completion_kind (guint kind)
 
   return kind;
 }
+
+/**
+ * ide_lsp_decode_text_edit:
+ * @text_edit: an lsp text edit encoded in a variant
+ * @file: The file the edit should be applied to
+ *
+ * Attempt to parse an encoded LSP text edit into an #IdeTextEdit.
+ *
+ * See specification
+ * https://microsoft.github.io/language-server-protocol/specifications/specification-current/#textEdit
+ * for further details.
+ *
+ * Returns: (transfer full) (nullable): an #IdeTextEdit
+ *
+ * Since: 41
+ */
+IdeTextEdit *
+ide_lsp_decode_text_edit (GVariant *text_edit, GFile *gfile)
+{
+  g_autoptr(IdeLocation) begin_location = NULL;
+  g_autoptr(IdeLocation) end_location = NULL;
+  g_autoptr(IdeRange) range = NULL;
+  const gchar *new_text = NULL;
+  gboolean success;
+  struct {
+    gint64 line;
+    gint64 column;
+  } begin, end;
+
+  success = JSONRPC_MESSAGE_PARSE (text_edit,
+    "range", "{",
+      "start", "{",
+        "line", JSONRPC_MESSAGE_GET_INT64 (&begin.line),
+        "character", JSONRPC_MESSAGE_GET_INT64 (&begin.column),
+      "}",
+      "end", "{",
+        "line", JSONRPC_MESSAGE_GET_INT64 (&end.line),
+        "character", JSONRPC_MESSAGE_GET_INT64 (&end.column),
+      "}",
+    "}",
+    "newText", JSONRPC_MESSAGE_GET_STRING (&new_text)
+  );
+
+  if (!success)
+    {
+      IDE_TRACE_MSG ("Failed to extract text edit from variant");
+      return NULL;
+    }
+
+  begin_location = ide_location_new (gfile, begin.line, begin.column);
+  end_location = ide_location_new (gfile, end.line, end.column);
+  range = ide_range_new (begin_location, end_location);
+
+  return ide_text_edit_new (range, new_text);
+
+}
