@@ -35,7 +35,7 @@ struct _IdeDebuggerLogView
   IdeDebugger *debugger;
 };
 
-G_DEFINE_TYPE (IdeDebuggerLogView, ide_debugger_log_view, GTK_TYPE_BOX)
+G_DEFINE_FINAL_TYPE (IdeDebuggerLogView, ide_debugger_log_view, GTK_TYPE_BOX)
 
 enum {
   PROP_0,
@@ -52,13 +52,13 @@ ide_debugger_log_view_new (void)
 }
 
 static void
-ide_debugger_log_view_finalize (GObject *object)
+ide_debugger_log_view_dispose (GObject *object)
 {
   IdeDebuggerLogView *self = (IdeDebuggerLogView *)object;
 
   g_clear_object (&self->debugger);
 
-  G_OBJECT_CLASS (ide_debugger_log_view_parent_class)->finalize (object);
+  G_OBJECT_CLASS (ide_debugger_log_view_parent_class)->dispose (object);
 }
 
 static void
@@ -74,6 +74,7 @@ ide_debugger_log_view_get_property (GObject    *object,
     case PROP_DEBUGGER:
       g_value_set_object (value, ide_debugger_log_view_get_debugger (self));
       break;
+
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
     }
@@ -92,6 +93,7 @@ ide_debugger_log_view_set_property (GObject      *object,
     case PROP_DEBUGGER:
       ide_debugger_log_view_set_debugger (self, g_value_get_object (value));
       break;
+
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
     }
@@ -161,7 +163,7 @@ ide_debugger_log_view_class_init (IdeDebuggerLogViewClass *klass)
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
   GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
-  object_class->finalize = ide_debugger_log_view_finalize;
+  object_class->dispose = ide_debugger_log_view_dispose;
   object_class->get_property = ide_debugger_log_view_get_property;
   object_class->set_property = ide_debugger_log_view_set_property;
 
@@ -237,7 +239,8 @@ ide_debugger_log_view_set_debugger (IdeDebuggerLogView *self,
   g_return_if_fail (IDE_IS_DEBUGGER_LOG_VIEW (self));
   g_return_if_fail (!debugger || IDE_IS_DEBUGGER (debugger));
 
-  self->debugger = g_object_ref (debugger);
+  if (g_set_object (&self->debugger, debugger))
+    g_object_notify_by_pspec (G_OBJECT (self), properties [PROP_DEBUGGER]);
 }
 
 IdeDebugger *
