@@ -70,6 +70,7 @@ struct _IpcFlatpakServiceImpl
   GHashTable *installs;
   GPtrArray *runtimes;
   GPtrArray *installs_ordered;
+  guint ignore_system_installations : 1;
 };
 
 static void      ipc_flatpak_service_impl_install_changed_cb (IpcFlatpakServiceImpl  *self,
@@ -94,6 +95,14 @@ static gboolean  runtime_equal                               (const Runtime
                                                               const Runtime          *b);
 static void      is_known_free                               (IsKnown                *state);
 
+enum {
+  PROP_0,
+  PROP_IGNORE_SYSTEM_INSTALLATIONS,
+  N_PROPS
+};
+
+static GParamSpec *properties [N_PROPS];
+
 static void
 resolve_extension_state_free (ResolveExtensionState *state)
 {
@@ -250,9 +259,9 @@ static gboolean
 runtime_equal (const Runtime *a,
                const Runtime *b)
 {
-  return g_str_equal (a->name, b->name) &&
-         g_str_equal (a->arch, b->arch) &&
-         g_str_equal (a->branch, b->branch);
+  return str_equal0 (a->name, b->name) &&
+         str_equal0 (a->arch, b->arch) &&
+         str_equal0 (a->branch, b->branch);
 }
 
 static Install *
@@ -393,21 +402,10 @@ install_reload (IpcFlatpakServiceImpl *self,
 }
 
 static gboolean
-has_private_repo (GPtrArray *installs)
+is_private_install (const Install *install)
 {
-  if (installs == NULL)
-    return FALSE;
-
-  for (guint i = installs->len; i > 0; i--)
-    {
-      Install *install = g_ptr_array_index (installs, i-1);
-
-      if (g_strcmp0 ("gnome-builder-private",
-                     flatpak_installation_get_id (install->installation)) == 0)
-        return TRUE;
-    }
-
-  return FALSE;
+  return g_strcmp0 ("gnome-builder-private",
+                    flatpak_installation_get_id (install->installation)) == 0;
 }
 
 static gboolean
@@ -417,6 +415,7 @@ add_installation (IpcFlatpakServiceImpl  *self,
 {
   g_autoptr(GFile) file = NULL;
   Install *install;
+  int position = -1;
 
   g_assert (IPC_IS_FLATPAK_SERVICE_IMPL (self));
   g_assert (FLATPAK_IS_INSTALLATION (installation));
@@ -426,19 +425,29 @@ add_installation (IpcFlatpakServiceImpl  *self,
   if (!(install = install_new (self, installation, error)))
     return FALSE;
 
-  install_reload (self, install);
+  for (guint i = 0; i < self->installs_ordered->len; i++)
+    {
+      const Install *other = g_ptr_array_index (self->installs_ordered, i);
 
-  /* Keep our private repo at the tail of the array */
-  if (has_private_repo (self->installs_ordered))
-    g_ptr_array_insert (self->installs_ordered,
-                        self->installs_ordered->len - 1,
-                        install);
+      if ((flatpak_installation_get_is_user (install->installation) &&
+           !flatpak_installation_get_is_user (other->installation)) ||
+          is_private_install (other))
+        {
+          position = i;
+          break;
+        }
+    }
+
+  if (position > -1)
+    g_ptr_array_insert (self->installs_ordered, position, install);
   else
     g_ptr_array_add (self->installs_ordered, install);
 
   g_hash_table_insert (self->installs,
                        g_steal_pointer (&file),
-                       g_steal_pointer (&install));
+                       install);
+
+  install_reload (self, install);
 
   return TRUE;
 }
@@ -458,6 +467,8 @@ ipc_flatpak_service_impl_add_installation (IpcFlatpakService     *service,
   g_assert (G_IS_DBUS_METHOD_INVOCATION (invocation));
   g_assert (path != NULL);
 
+  g_debug ("AddInstallation(%s, is_user=%d)", path, is_user);
+
   file = g_file_new_for_path (path);
 
   if (!g_hash_table_contains (self->installs, file))
@@ -482,6 +493,8 @@ ipc_flatpak_service_impl_list_runtimes (IpcFlatpakService     *service,
   g_assert (IPC_IS_FLATPAK_SERVICE_IMPL (self));
   g_assert (G_IS_DBUS_METHOD_INVOCATION (invocation));
 
+  g_debug ("ListRuntimes()");
+
   g_variant_builder_init (&builder, RUNTIME_ARRAY_VARIANT_TYPE);
 
   for (guint i = 0; i < self->runtimes->len; i++)
@@ -492,7 +505,7 @@ ipc_flatpak_service_impl_list_runtimes (IpcFlatpakService     *service,
     }
 
   ipc_flatpak_service_complete_list_runtimes (service,
-                                              invocation,
+                                              g_steal_pointer (&invocation),
                                               g_variant_builder_end (&builder));
 
   return TRUE;
@@ -533,12 +546,17 @@ is_known_worker (GTask        *task,
     flags |= FLATPAK_QUERY_FLAGS_ALL_ARCHES;
 #endif
 
+  g_debug ("%u installs available for IsKnown query",
+           state->installs->len);
+
   for (guint z = 0; z < state->installs->len; z++)
     {
       FlatpakInstallation *install = g_ptr_array_index (state->installs, z);
 
       if (!(remotes = flatpak_installation_list_remotes (install, NULL, &error)))
-        goto finish;
+        continue;
+
+      g_debug ("%u remotes found for installation %u", remotes->len, z);
 
       for (guint i = 0; i < remotes->len; i++)
         {
@@ -546,13 +564,26 @@ is_known_worker (GTask        *task,
           const char *remote_name = flatpak_remote_get_name (remote);
           g_autoptr(GPtrArray) refs = NULL;
 
+          g_debug ("Checking remote \"%s\" with flags 0x%x", remote_name, flags);
           if (!(refs = flatpak_installation_list_remote_refs_sync_full (install, remote_name, flags, NULL, NULL)))
-            continue;
+            {
+              g_debug ("Failed to access refs, skipping");
+              continue;
+            }
+
+          g_debug ("%u remote refs found", refs->len);
 
           for (guint j = 0; j < refs->len; j++)
             {
               FlatpakRemoteRef *remote_ref = g_ptr_array_index (refs, j);
 
+#if 0
+              g_debug ("Found remote ref: %s/%s/%s",
+                       flatpak_ref_get_name (FLATPAK_REF (remote_ref)),
+                       flatpak_ref_get_arch (FLATPAK_REF (remote_ref)),
+                       flatpak_ref_get_branch (FLATPAK_REF (remote_ref)));
+#endif
+
               if (str_equal0 (ref_name, flatpak_ref_get_name (FLATPAK_REF (remote_ref))) &&
                   str_equal0 (ref_arch, flatpak_ref_get_arch (FLATPAK_REF (remote_ref))) &&
                   str_equal0 (ref_branch, flatpak_ref_get_branch (FLATPAK_REF (remote_ref))))
@@ -566,6 +597,7 @@ is_known_worker (GTask        *task,
     }
 
 finish:
+  g_debug ("RuntimeIsKnown => (%d, %"G_GSIZE_FORMAT")", found, download_size);
   ipc_flatpak_service_complete_runtime_is_known (g_task_get_source_object (task),
                                                  g_steal_pointer (&state->invocation),
                                                  found,
@@ -592,6 +624,8 @@ ipc_flatpak_service_impl_runtime_is_known (IpcFlatpakService     *service,
   const char *ref_branch;
   IsKnown *state;
 
+  g_debug ("RuntimeIsKnown(%s)", name);
+
   g_assert (IPC_IS_FLATPAK_SERVICE_IMPL (self));
   g_assert (G_IS_DBUS_METHOD_INVOCATION (invocation));
   g_assert (name != NULL);
@@ -603,7 +637,7 @@ ipc_flatpak_service_impl_runtime_is_known (IpcFlatpakService     *service,
 
   /* Parse the ref, so we can try to locate it */
   if (!(ref = flatpak_ref_parse (full_name, &error)))
-    return complete_wrapped_error (invocation, error);
+    return complete_wrapped_error (g_steal_pointer (&invocation), error);
 
   ref_name = flatpak_ref_get_name (ref);
   ref_arch = flatpak_ref_get_arch (ref);
@@ -614,11 +648,13 @@ ipc_flatpak_service_impl_runtime_is_known (IpcFlatpakService     *service,
     {
       const Runtime *runtime = g_ptr_array_index (self->runtimes, i);
 
-      if (g_str_equal (ref_name, runtime->name) &&
-          g_str_equal (ref_arch, runtime->arch) &&
-          g_str_equal (ref_branch, runtime->branch))
+      if (str_equal0 (ref_name, runtime->name) &&
+          str_equal0 (ref_arch, runtime->arch) &&
+          str_equal0 (ref_branch, runtime->branch))
         {
-          ipc_flatpak_service_complete_runtime_is_known (service, invocation, TRUE, 0);
+          ipc_flatpak_service_complete_runtime_is_known (service,
+                                                         g_steal_pointer (&invocation),
+                                                         TRUE, 0);
           return TRUE;
         }
     }
@@ -675,6 +711,7 @@ typedef struct
   FlatpakRef *fref;
   char *ref;
   char *remote;
+  guint update : 1;
 } InstallRef;
 
 typedef struct
@@ -742,7 +779,6 @@ install_worker (GTask        *task,
                 GCancellable *cancellable)
 {
   InstallState *state = task_data;
-  IpcFlatpakServiceImpl *self = source_object;
   g_autoptr(GError) error = NULL;
   g_autoptr(GPtrArray) ref_ids = NULL;
   g_autoptr(GHashTable) transactions = NULL;
@@ -774,7 +810,7 @@ install_worker (GTask        *task,
   if (!ipc_flatpak_transfer_call_confirm_sync (state->transfer, (const char * const *)ref_ids->pdata, state->cancellable, &error))
     {
       g_warning ("User confirmation failed: %s", error->message);
-      complete_wrapped_error (g_steal_pointer (&state->invocation), g_steal_pointer (&error));
+      complete_wrapped_error (g_steal_pointer (&state->invocation), g_error_copy (error));
       g_task_return_error (task, g_steal_pointer (&error));
       return;
     }
@@ -808,14 +844,25 @@ install_worker (GTask        *task,
         }
 
       /* Add ref as install or update to installation's transaction */
-      if ((is_installed (self, ir->fref) &&
-           !flatpak_transaction_add_update (transaction, ir->ref, NULL, NULL, &error)) ||
-          !flatpak_transaction_add_install (transaction, ir->remote, ir->ref, NULL, &error))
+      if (ir->update)
         {
-          g_warning ("Failed to add ref to transaction: %s", error->message);
-          complete_wrapped_error (g_steal_pointer (&state->invocation), g_error_copy (error));
-          g_task_return_error (task, g_steal_pointer (&error));
-          return;
+          if (!flatpak_transaction_add_update (transaction, ir->ref, NULL, NULL, &error))
+            {
+              g_warning ("Failed to add update ref to transaction: %s", error->message);
+              complete_wrapped_error (g_steal_pointer (&state->invocation), g_error_copy (error));
+              g_task_return_error (task, g_steal_pointer (&error));
+              return;
+            }
+        }
+      else
+        {
+          if (!flatpak_transaction_add_install (transaction, ir->remote, ir->ref, NULL, &error))
+            {
+              g_warning ("Failed to add install ref to transaction: %s", error->message);
+              complete_wrapped_error (g_steal_pointer (&state->invocation), g_error_copy (error));
+              g_task_return_error (task, g_steal_pointer (&error));
+              return;
+            }
         }
     }
 
@@ -844,9 +891,9 @@ install_worker (GTask        *task,
 
   ipc_flatpak_transfer_set_fraction (state->transfer, 1.0);
   ipc_flatpak_transfer_set_message (state->transfer, _("Installation complete"));
-  ipc_flatpak_service_complete_install (source_object, g_steal_pointer (&state->invocation));
-
   g_task_return_boolean (task, TRUE);
+
+  /* GDBusMethodInvocation completes on the main thread */
 }
 
 static gboolean
@@ -890,7 +937,10 @@ find_remote_for_ref (IpcFlatpakServiceImpl  *self,
       Install *install = g_ptr_array_index (self->installs_ordered, i);
       g_autoptr(GPtrArray) remotes = flatpak_installation_list_remotes (install->installation, NULL, NULL);
 
-      if (remotes == NULL)
+      /* Ignore if failure or this is a system installation (as we can't install
+       * anything for that).
+       */
+      if (remotes == NULL || !flatpak_installation_get_is_user (install->installation))
         continue;
 
       for (guint j = 0; j < remotes->len; j++)
@@ -960,9 +1010,13 @@ find_installations_for_refs (IpcFlatpakServiceImpl *self,
         {
           const Runtime *r = g_ptr_array_index (self->runtimes, j);
 
+          /* Check for matching ref, but also that installation is going
+           * to be writable to us from the sandbox.
+           */
           if (str_equal0 (name, r->name) &&
               str_equal0 (arch, r->arch) &&
-              str_equal0 (branch, r->branch))
+              str_equal0 (branch, r->branch) &&
+              flatpak_installation_get_is_user (r->installation))
             {
               g_ptr_array_add (installations, g_object_ref (r->installation));
               goto next_ref;
@@ -990,10 +1044,47 @@ find_installations_for_refs (IpcFlatpakServiceImpl *self,
   return installations;
 }
 
+static void
+on_install_completed_cb (IpcFlatpakServiceImpl *self,
+                         GParamSpec            *pspec,
+                         GTask                 *task)
+{
+  g_autoptr(GDBusMethodInvocation) invocation = NULL;
+  GHashTableIter iter;
+  Install *install;
+
+  g_assert (IPC_IS_FLATPAK_SERVICE_IMPL (self));
+  g_assert (G_IS_TASK (task));
+
+  /* Steal the invocation object */
+  invocation = g_object_ref (g_object_get_data (G_OBJECT (task), "INVOCATION"));
+  g_object_set_data (G_OBJECT (task), "INVOCATION", NULL);
+
+  if (g_task_had_error (task))
+    return;
+
+  /* Reload installations so that we pick up new runtimes
+   * immediately before we notify the install completed. Otherwise
+   * we risk not being able to access it from the UI when the
+   * D-Bus completion comes in.
+   */
+  g_hash_table_iter_init (&iter, self->installs);
+  while (g_hash_table_iter_next (&iter, NULL, (gpointer *)&install))
+    {
+      if (flatpak_installation_get_is_user (install->installation))
+        install_reload (self, install);
+    }
+
+  /* Now notify the client */
+  ipc_flatpak_service_complete_install (IPC_FLATPAK_SERVICE (self),
+                                        g_steal_pointer (&invocation));
+}
+
 static gboolean
 ipc_flatpak_service_impl_install (IpcFlatpakService     *service,
                                   GDBusMethodInvocation *invocation,
                                   const char * const    *full_ref_names,
+                                  gboolean               if_not_exists,
                                   const char            *transfer_path,
                                   const char            *parent_window)
 {
@@ -1001,6 +1092,7 @@ ipc_flatpak_service_impl_install (IpcFlatpakService     *service,
   g_autoptr(IpcFlatpakTransfer) transfer = NULL;
   g_autoptr(GArray) refs = NULL;
   g_autoptr(GTask) task = NULL;
+  g_autofree char *debug_str = NULL;
   GDBusConnection *connection;
   InstallState *state;
 
@@ -1010,6 +1102,10 @@ ipc_flatpak_service_impl_install (IpcFlatpakService     *service,
   g_assert (transfer_path != NULL);
   g_assert (parent_window != NULL);
 
+  debug_str = g_strjoinv (", ", (char **)full_ref_names);
+  g_debug ("Install([%s], if_not_exists=%d, transfer=%s, parent_window=%s)",
+           debug_str, if_not_exists, transfer_path, parent_window);
+
   refs = g_array_new (FALSE, FALSE, sizeof (InstallRef));
   g_array_set_clear_func (refs, clear_install_ref);
 
@@ -1033,11 +1129,20 @@ ipc_flatpak_service_impl_install (IpcFlatpakService     *service,
 
   for (guint i = 0; full_ref_names[i]; i++)
     {
-      g_autoptr(FlatpakRef) ref = flatpak_ref_parse (full_ref_names[i], NULL);
+      const char *name = full_ref_names[i];
+      g_autoptr(FlatpakRef) ref = NULL;
+      g_autofree char *adjusted = NULL;
       InstallRef iref = {0};
 
-      if (ref != NULL && is_installed (self, ref))
-        continue;
+      if (!g_str_has_prefix (name, "runtime/") && !g_str_has_prefix (name, "app/"))
+        name = adjusted = g_strdup_printf ("runtime/%s", full_ref_names[i]);
+
+      if ((ref = flatpak_ref_parse (name, NULL)))
+        {
+          iref.update = is_installed (self, ref);
+          if (if_not_exists && iref.update)
+            continue;
+        }
 
       if (ref == NULL ||
           !(iref.remote = find_remote_for_ref (self, ref, NULL)))
@@ -1050,8 +1155,8 @@ ipc_flatpak_service_impl_install (IpcFlatpakService     *service,
           return TRUE;
         }
 
+      iref.ref = flatpak_ref_format_ref (ref);
       iref.fref = g_steal_pointer (&ref);
-      iref.ref = g_strdup (full_ref_names[i]);
       g_array_append_val (refs, iref);
     }
 
@@ -1063,7 +1168,7 @@ ipc_flatpak_service_impl_install (IpcFlatpakService     *service,
 
   state = g_slice_new0 (InstallState);
   state->cancellable = g_cancellable_new ();
-  state->invocation = g_steal_pointer (&invocation);
+  state->invocation = g_object_ref (invocation);
   state->refs = g_array_ref (refs);
   state->parent_window = parent_window[0] ? g_strdup (parent_window) : NULL;
   state->transfer = g_object_ref (transfer);
@@ -1079,10 +1184,21 @@ ipc_flatpak_service_impl_install (IpcFlatpakService     *service,
                            G_CONNECT_SWAPPED);
 
   task = g_task_new (self, state->cancellable, NULL, NULL);
+  g_object_set_data_full (G_OBJECT (task),
+                          "INVOCATION",
+                          g_object_ref (invocation),
+                          g_object_unref);
+  g_signal_connect_object (task,
+                           "notify::completed",
+                           G_CALLBACK (on_install_completed_cb),
+                           self,
+                           G_CONNECT_SWAPPED);
   g_task_set_source_tag (task, ipc_flatpak_service_impl_install);
   g_task_set_task_data (task, state, (GDestroyNotify)install_state_free);
   g_task_run_in_thread (task, install_worker);
 
+  g_object_unref (invocation);
+
   return TRUE;
 }
 
@@ -1355,6 +1471,8 @@ ipc_flatpak_service_impl_resolve_extension (IpcFlatpakService     *service,
   g_assert (sdk != NULL);
   g_assert (extension != NULL);
 
+  g_debug ("ResolveExtension(%s, %s)", sdk, extension);
+
   if (g_str_has_prefix (sdk, "runtime/"))
     sdk += strlen ("runtime/");
 
@@ -1394,6 +1512,8 @@ ipc_flatpak_service_impl_get_runtime (IpcFlatpakService     *service,
   g_assert (G_IS_DBUS_METHOD_INVOCATION (invocation));
   g_assert (runtime_id != NULL);
 
+  g_debug ("GetRuntime(%s)", runtime_id);
+
   /* Homogenize names into runtime/name/arch/branch */
   if (g_str_has_prefix (runtime_id, "runtime/"))
     runtime_id += strlen ("runtime/");
@@ -1446,7 +1566,7 @@ service_iface_init (IpcFlatpakServiceIface *iface)
 }
 
 G_DEFINE_FINAL_TYPE_WITH_CODE (IpcFlatpakServiceImpl, ipc_flatpak_service_impl, IPC_TYPE_FLATPAK_SERVICE_SKELETON,
-                         G_IMPLEMENT_INTERFACE (IPC_TYPE_FLATPAK_SERVICE, service_iface_init))
+                               G_IMPLEMENT_INTERFACE (IPC_TYPE_FLATPAK_SERVICE, service_iface_init))
 
 static void
 ipc_flatpak_service_impl_constructed (GObject *object)
@@ -1460,16 +1580,17 @@ ipc_flatpak_service_impl_constructed (GObject *object)
 
   G_OBJECT_CLASS (ipc_flatpak_service_impl_parent_class)->constructed (object);
 
-  ipc_flatpak_service_set_default_arch (IPC_FLATPAK_SERVICE (self), flatpak_get_default_arch ());
+  ipc_flatpak_service_set_default_arch (IPC_FLATPAK_SERVICE (self),
+                                        flatpak_get_default_arch ());
 
-  user_file = g_file_new_build_filename (g_get_home_dir (), ".local", "share", "flatpak", NULL);
-  if ((user = flatpak_installation_new_for_path (user_file, TRUE, NULL, NULL)))
-    add_installation (self, user, NULL);
-
-  if ((installations = flatpak_get_system_installations (NULL, NULL)))
+  /* Add system installations unless disabled */
+  if (!self->ignore_system_installations)
     {
-      for (guint i = 0; i < installations->len; i++)
-        add_installation (self, g_ptr_array_index (installations, i), NULL);
+      if ((installations = flatpak_get_system_installations (NULL, NULL)))
+        {
+          for (guint i = 0; i < installations->len; i++)
+            add_installation (self, g_ptr_array_index (installations, i), NULL);
+        }
     }
 
   /* Fallback for SDKs not available elsewhere */
@@ -1497,6 +1618,43 @@ ipc_flatpak_service_impl_finalize (GObject *object)
   G_OBJECT_CLASS (ipc_flatpak_service_impl_parent_class)->finalize (object);
 }
 
+static void
+ipc_flatpak_service_impl_get_property (GObject    *object,
+                                       guint       prop_id,
+                                       GValue     *value,
+                                       GParamSpec *pspec)
+{
+  IpcFlatpakServiceImpl *self = IPC_FLATPAK_SERVICE_IMPL (object);
+
+  switch (prop_id)
+    {
+    case PROP_IGNORE_SYSTEM_INSTALLATIONS:
+      g_value_set_boolean (value, self->ignore_system_installations);
+      break;
+    default:
+      G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+    }
+}
+
+static void
+ipc_flatpak_service_impl_set_property (GObject      *object,
+                                       guint         prop_id,
+                                       const GValue *value,
+                                       GParamSpec   *pspec)
+{
+  IpcFlatpakServiceImpl *self = IPC_FLATPAK_SERVICE_IMPL (object);
+
+  switch (prop_id)
+    {
+    case PROP_IGNORE_SYSTEM_INSTALLATIONS:
+      self->ignore_system_installations = g_value_get_boolean (value);
+      break;
+
+    default:
+      G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+    }
+}
+
 static void
 ipc_flatpak_service_impl_class_init (IpcFlatpakServiceImplClass *klass)
 {
@@ -1504,6 +1662,17 @@ ipc_flatpak_service_impl_class_init (IpcFlatpakServiceImplClass *klass)
 
   object_class->constructed = ipc_flatpak_service_impl_constructed;
   object_class->finalize = ipc_flatpak_service_impl_finalize;
+  object_class->get_property = ipc_flatpak_service_impl_get_property;
+  object_class->set_property = ipc_flatpak_service_impl_set_property;
+
+  properties [PROP_IGNORE_SYSTEM_INSTALLATIONS] =
+    g_param_spec_boolean ("ignore-system-installations",
+                          "Ignore System Installations",
+                          "Ignore System Installations",
+                          FALSE,
+                          (G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS));
+
+  g_object_class_install_properties (object_class, N_PROPS, properties);
 }
 
 static void
@@ -1518,7 +1687,9 @@ ipc_flatpak_service_impl_init (IpcFlatpakServiceImpl *self)
 }
 
 IpcFlatpakService *
-ipc_flatpak_service_impl_new (void)
+ipc_flatpak_service_impl_new (gboolean ignore_system_installations)
 {
-  return g_object_new (IPC_TYPE_FLATPAK_SERVICE_IMPL, NULL);
+  return g_object_new (IPC_TYPE_FLATPAK_SERVICE_IMPL,
+                       "ignore-system-installations", ignore_system_installations,
+                       NULL);
 }
