@@ -160,15 +160,15 @@ static void
 gbp_flatpak_runtime_provider_load (IdeRuntimeProvider *provider,
                                    IdeRuntimeManager  *manager)
 {
-  g_autoptr(GbpFlatpakClient) client = NULL;
   g_autoptr(IpcFlatpakService) service = NULL;
   g_autoptr(IdeContext) context = NULL;
+  GbpFlatpakClient *client;
 
   g_assert (GBP_IS_FLATPAK_RUNTIME_PROVIDER (provider));
   g_assert (IDE_IS_RUNTIME_MANAGER (manager));
 
   if ((context = ide_object_ref_context (IDE_OBJECT (provider))) &&
-      (client = gbp_flatpak_client_ensure (context)) &&
+      (client = gbp_flatpak_client_get_default ()) &&
       (service = gbp_flatpak_client_get_service (client, NULL, NULL)))
     {
       g_signal_connect_object (service,
@@ -318,6 +318,7 @@ gbp_flatpak_runtime_provider_bootstrap_complete (gpointer data)
 
       ipc_flatpak_service_call_install (state->service,
                                         (const char * const *)state->to_install->pdata,
+                                        TRUE,
                                         state->transfer_path,
                                         "",
                                         ide_task_get_cancellable (task),
@@ -345,11 +346,12 @@ gbp_flatpak_runtime_provider_bootstrap (IdeTask      *task,
                                         GCancellable *cancellable)
 {
   g_autoptr(IdeContext) context = NULL;
-  g_autoptr(GbpFlatpakClient) client = NULL;
   g_autoptr(IpcFlatpakService) service = NULL;
   g_autoptr(IpcFlatpakTransfer) transfer = NULL;
   g_autoptr(IdeNotification) notif = NULL;
   Bootstrap *state = task_data;
+  g_autoptr(GString) debug_install = NULL;
+  GbpFlatpakClient *client;
 
   IDE_ENTRY;
 
@@ -360,7 +362,7 @@ gbp_flatpak_runtime_provider_bootstrap (IdeTask      *task,
   g_assert (state->to_install->len > 0);
 
   if (!(context = ide_object_ref_context (source_object)) ||
-      !(client = gbp_flatpak_client_ensure (context)) ||
+      !(client = gbp_flatpak_client_get_default ()) ||
       !(service = gbp_flatpak_client_get_service (client, NULL, NULL)))
     {
       ide_task_return_new_error (task,
@@ -370,6 +372,15 @@ gbp_flatpak_runtime_provider_bootstrap (IdeTask      *task,
       IDE_GOTO (failure);
     }
 
+  debug_install = g_string_new (NULL);
+  for (guint i = 0; i < state->to_install->len; i++)
+    g_string_append_printf (debug_install,
+                            "%s, ",
+                            (char *)g_ptr_array_index(state->to_install, i));
+  if (debug_install->len > 2)
+    g_string_truncate (debug_install, debug_install->len-2);
+  g_debug ("Needed flatpak runtimes: %s", debug_install->str);
+
   /* Filter out anything we can't find or is already installed */
   for (guint i = state->to_install->len; i > 0; i--)
     {
