@@ -330,7 +330,7 @@ class GnomeGTK4ProjectTemplate(MesonTemplate):
             _('GNOME Application'),
             'pattern-gnome',
             _('Create a GNOME application with GTK 4'),
-            ['C'],
+            ['C', 'Rust', 'Python', 'Vala'],
             0
          )
 
@@ -373,8 +373,9 @@ class GnomeGTK4ProjectTemplate(MesonTemplate):
             resource_name = None
             window_ui_name = None
         elif self.language == 'vala':
-            files['resources/src/main.vala'] = 'src/main.vala'
-            files['resources/src/window.vala'] = 'src/window.vala'
+            files['resources/src/main-gtk4.vala'] = 'src/main.vala'
+            files['resources/src/window-gtk4.vala'] = 'src/window.vala'
+            files['resources/src/application-gtk4.vala'] = 'src/application.vala'
         elif self.language == 'javascript':
             files['resources/src/main.js.tmpl'] = 'src/main.js'
             files['resources/src/hello.js.in'] = 'src/%(appid)s.in'
@@ -385,17 +386,18 @@ class GnomeGTK4ProjectTemplate(MesonTemplate):
         elif self.language == 'python':
             files['resources/src/hello.py.in'] = 'src/%(name)s.in'
             files['resources/src/__init__.py'] = 'src/__init__.py'
-            files['resources/src/window.py'] = 'src/window.py'
-            files['resources/src/main.py'] = 'src/main.py'
-            meson_file = 'resources/src/meson-py.build'
+            files['resources/src/window-gtk4.py'] = 'src/window.py'
+            files['resources/src/main-gtk4.py'] = 'src/main.py'
+            meson_file = 'resources/src/meson-py-gtk4.build'
         elif self.language == 'rust':
-            files['resources/src/config.rs.in'] = 'src/config.rs.in'
-            files['resources/src/main.rs'] = 'src/main.rs'
-            files['resources/src/window.rs'] = 'src/window.rs'
+            files['resources/src/application.rs'] = 'src/application.rs'
+            files['resources/src/config-gtk4.rs.in'] = 'src/config.rs.in'
+            files['resources/src/main-gtk4.rs'] = 'src/main.rs'
+            files['resources/src/window-gtk4.rs'] = 'src/window.rs'
             files['resources/src/Cargo.lock'] = 'Cargo.lock'
-            files['resources/src/Cargo.toml'] = 'Cargo.toml'
+            files['resources/src/Cargo-gtk4.toml'] = 'Cargo.toml'
             files['resources/build-aux/cargo.sh'] = 'build-aux/cargo.sh'
-            meson_file = 'resources/src/meson-rs.build'
+            meson_file = 'resources/src/meson-rs-gtk4.build'
 
         if resource_name:
             files['resources/src/hello.gresource.xml'] = resource_name
