@@ -63,7 +63,7 @@ on_build_stage_query (IdePipelineStage *stage,
         break;
     }
   g_ptr_array_add (replace, NULL);
-  ide_subprocess_launcher_set_argv (launcher, (gchar **)replace->pdata);
+  ide_subprocess_launcher_set_argv (launcher, (const gchar * const *)replace->pdata);
 
   /* If we have targets to build, specify them */
   if (targets != NULL)
@@ -147,7 +147,16 @@ gbp_meson_pipeline_addin_load (IdePipelineAddin *addin,
   g_assert (IDE_IS_RUNTIME (runtime));
   g_assert (srcdir != NULL);
 
-  for (guint i = 0; i < G_N_ELEMENTS (ninja_names); i++)
+  if (NULL == (meson = ide_config_getenv (config, "MESON")))
+    meson = "meson";
+
+  /* Warn about not finding Meson, but continue setting up */
+  if (!ide_runtime_contains_program_in_path (runtime, meson, NULL))
+    ide_context_warning (context,
+                         _("A Meson-based project is loaded but meson could not be found."));
+
+  /* Requires NULL check so we can use g_strv_contains() elsewhere */
+  for (guint i = 0; ninja_names[i]; i++)
     {
       if (ide_runtime_contains_program_in_path (runtime, ninja_names[i], NULL))
         {
@@ -159,11 +168,12 @@ gbp_meson_pipeline_addin_load (IdePipelineAddin *addin,
   if (ninja == NULL)
     ninja = ide_config_getenv (config, "NINJA");
 
+  /* Warn about not finding ninja, but continue setting up */
   if (ninja == NULL)
     {
       ide_context_warning (context,
                            _("A Meson-based project is loaded but Ninja could not be found."));
-      IDE_EXIT;
+      ninja = "ninja";
     }
 
   /* Create all our launchers up front */
@@ -177,13 +187,6 @@ gbp_meson_pipeline_addin_load (IdePipelineAddin *addin,
   config_opts = ide_config_get_config_opts (config);
   parallel = ide_config_get_parallelism (config);
 
-  if (NULL == (meson = ide_config_getenv (config, "MESON")))
-    meson = "meson";
-
-  if (!ide_runtime_contains_program_in_path (runtime, meson, NULL))
-    ide_context_warning (context,
-                         _("A Meson-based project is loaded but meson could not be found."));
-
   /* Create the toolchain file if required */
   if (GBP_IS_MESON_TOOLCHAIN (toolchain))
     crossbuild_file = g_strdup (gbp_meson_toolchain_get_file_path (GBP_MESON_TOOLCHAIN (toolchain)));
@@ -279,7 +282,7 @@ pipeline_addin_iface_init (IdePipelineAddinInterface *iface)
   iface->load = gbp_meson_pipeline_addin_load;
 }
 
-G_DEFINE_TYPE_WITH_CODE (GbpMesonPipelineAddin, gbp_meson_pipeline_addin, IDE_TYPE_OBJECT,
+G_DEFINE_FINAL_TYPE_WITH_CODE (GbpMesonPipelineAddin, gbp_meson_pipeline_addin, IDE_TYPE_OBJECT,
                          G_IMPLEMENT_INTERFACE (IDE_TYPE_PIPELINE_ADDIN,
                                                 pipeline_addin_iface_init))
 
