@@ -236,7 +236,7 @@ typedef struct
 static void gbp_omni_gutter_renderer_reload_icons (GbpOmniGutterRenderer *self);
 static void gutter_iface_init                     (IdeGutterInterface    *iface);
 
-G_DEFINE_TYPE_WITH_CODE (GbpOmniGutterRenderer,
+G_DEFINE_FINAL_TYPE_WITH_CODE (GbpOmniGutterRenderer,
                          gbp_omni_gutter_renderer,
                          GTK_SOURCE_TYPE_GUTTER_RENDERER,
                          G_IMPLEMENT_INTERFACE (IDE_TYPE_GUTTER, gutter_iface_init))
@@ -385,7 +385,9 @@ static void
 reload_style_colors (GbpOmniGutterRenderer *self,
                      GtkSourceStyleScheme  *scheme)
 {
+  GtkStyleContext *context;
   GtkTextView *view;
+  GtkStateFlags state;
   GdkRGBA fg;
   GdkRGBA bg;
 
@@ -396,8 +398,12 @@ reload_style_colors (GbpOmniGutterRenderer *self,
   if (view == NULL)
     return;
 
-  get_style_rgba (scheme, "line-numbers", FOREGROUND, &fg);
-  get_style_rgba (scheme, "line-numbers", BACKGROUND, &bg);
+  context = gtk_widget_get_style_context (GTK_WIDGET (view));
+  state = gtk_style_context_get_state (context);
+  gtk_style_context_get_color (context, state, &fg);
+  G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
+  gtk_style_context_get_background_color (context, state, &bg);
+  G_GNUC_END_IGNORE_DEPRECATIONS;
 
   /* Extract common values from style schemes. */
   if (!get_style_rgba (scheme, "line-numbers", FOREGROUND, &self->text.fg))
@@ -535,9 +541,11 @@ populate_diagnostics_cb (guint                 line,
   g_assert (line <= state->end_line);
 
   info = &g_array_index (state->lines, LineInfo, line - state->begin_line);
-  info->is_warning |= !!(severity & (IDE_DIAGNOSTIC_WARNING | IDE_DIAGNOSTIC_DEPRECATED));
-  info->is_error |= !!(severity & (IDE_DIAGNOSTIC_ERROR | IDE_DIAGNOSTIC_FATAL));
-  info->is_note |= !!(severity & IDE_DIAGNOSTIC_NOTE);
+  info->is_warning |= severity == IDE_DIAGNOSTIC_WARNING
+                      || severity == IDE_DIAGNOSTIC_DEPRECATED
+                      || severity == IDE_DIAGNOSTIC_UNUSED;
+  info->is_error |= severity == IDE_DIAGNOSTIC_ERROR || severity == IDE_DIAGNOSTIC_FATAL;
+  info->is_note |= severity == IDE_DIAGNOSTIC_NOTE;
 }
 
 static void
@@ -1405,11 +1413,11 @@ gbp_omni_gutter_renderer_reload_icons (GbpOmniGutterRenderer *self)
 
   self->note_surface = get_icon_surface (self, GTK_WIDGET (view), "dialog-information-symbolic", self->diag_size, FALSE);
   self->warning_surface = get_icon_surface (self, GTK_WIDGET (view), "dialog-warning-symbolic", self->diag_size, FALSE);
-  self->error_surface = get_icon_surface (self, GTK_WIDGET (view), "process-stop-symbolic", self->diag_size, FALSE);
+  self->error_surface = get_icon_surface (self, GTK_WIDGET (view), "builder-build-stop-symbolic", self->diag_size, FALSE);
 
   self->note_selected_surface = get_icon_surface (self, GTK_WIDGET (view), "dialog-information-symbolic", self->diag_size, TRUE);
   self->warning_selected_surface = get_icon_surface (self, GTK_WIDGET (view), "dialog-warning-symbolic", self->diag_size, TRUE);
-  self->error_selected_surface = get_icon_surface (self, GTK_WIDGET (view), "process-stop-symbolic", self->diag_size, TRUE);
+  self->error_selected_surface = get_icon_surface (self, GTK_WIDGET (view), "builder-build-stop-symbolic", self->diag_size, TRUE);
 }
 
 static void
